/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.objectweb.petals.tools.rmi.common.serializable;

import java.io.Serializable;

import javax.xml.namespace.QName;

/**
 * RMI implementation of service endpoint.
 * @author Nicolas Salatge - EBM WebSourcing
 */
public class ServiceEndpoint
implements javax.jbi.servicedesc.ServiceEndpoint, Serializable {

    /**
     * default serialVersionUID.
     */
    private static final long serialVersionUID = 1L;

    /**
     * the endpoint name.
     */
    private String endpointName = null;

    /**
     * the interfaces.
     */
    private QName[] interfaces = null;

    /**
     * the service name.
     */
    private QName serviceName = null;


    /**
     * the default constructor.
     * @param serviceName
     *          the service name
     * @param endpointName
     *          the endpoint name
     * @param interfaces
     *          the interfaces
     */
    public ServiceEndpoint(final QName serviceName,
            final String endpointName, final QName[] interfaces) {
        this.endpointName = endpointName;
        this.interfaces = interfaces;
        this.serviceName = serviceName;
    }

    /**
     * Get the endpoint name.
     * @return
     *       the endpoint name
     */
    public String getEndpointName() {
        return this.endpointName;
    }

    /**
     * Get interfaces.
     * @return
     *       the interfaces.
     */
    public QName[] getInterfaces() {
        return this.interfaces;
    }

    /**
     * Get service names.
     * @return
     *     the service name
     */
    public QName getServiceName() {
        return this.serviceName;
    }

    /**
     * Get the reference.
     * @param operationName
     *        the operation name
     * @return
     *     the document fragment
     */
    public org.w3c.dom.DocumentFragment getAsReference(final
            javax.xml.namespace.QName operationName) {
        throw new NoSuchMethodError("Not implemented.");
    }

    /** toString method.
     * @return the string representation of service endpoint
     */
    public String toString() {
        String res = "";
        res = res + "serviceName = " + this.serviceName;
        res = res + "endpointName = " + this.endpointName;
        res = res + "interfaces = " + String.valueOf(this.interfaces);
        return res;
    }
}
