/**
 * Copyright (c) 2006-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.objectweb.petals.tools.rmi.common.serializable.messagingtypes;

import java.io.Serializable;

import javax.jbi.messaging.MessagingException;
import javax.jbi.messaging.NormalizedMessage;

import org.objectweb.petals.tools.rmi.common.serializable.MessageExchange;

/**
 * This class is a InOut message.
 * @author Nicolas SALATGE - EBM WebSourcing
 */
public class InOut extends MessageExchange
implements javax.jbi.messaging.InOut, Serializable {

    /**
     * the serialVersionUID.
     */
    private static final long serialVersionUID = -5862043510976681305L;

    /**
     * the default constructor.
     *
     */
    public InOut() {
        super();

        this.setPattern(MessageExchange.IN_OUT_PATTERN);
    }

    /**
     * @see javax.jbi.messaging.InOnly#getInMessage()
     * @return
     *      the normalized message
     */
    public NormalizedMessage getInMessage() {
        return this.getMessage(MessageExchange.IN_MSG);
    }

    /**
     * @see javax.jbi.messaging.InOptionalOut#getOutMessage()
     * @return
     *      the normalzied message
     */
    public NormalizedMessage getOutMessage() {
        return this.getMessage(MessageExchange.OUT_MSG);
    }

    /**
     * @see javax.jbi.messaging.InOnly#setInMessage(javax.jbi.messaging.NormalizedMessage)
     * @param msg
     *         the normalized message
     * @throws MessagingException
     *         impossible to set the message
     */
    public void setInMessage(final NormalizedMessage msg) throws MessagingException {
        this.setMessage(msg, MessageExchange.IN_MSG);
    }

    /**
     * @see javax.jbi.messaging.InOptionalOut#setOutMessage(javax.jbi.messaging.NormalizedMessage)
     * @param msg
     *         the normalized message
     * @throws MessagingException
     *         impossible to set the message
     */
    public void setOutMessage(final NormalizedMessage msg) throws MessagingException {
        this.setMessage(msg, MessageExchange.OUT_MSG);
    }
}
